/*
** Module   : OperatingSystemInspector.java
** Abstract : Progress 4GL compatible OS system variables checking methods interface.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20140324 Created initial version.
*/

package com.goldencode.p2j.util;

/**
 * Interface describing the methods that gets different system variables and characteristics.
 * <p>
 * The accessor classes implementing this interface provide the way to access environment worker
 * classes on the client side.
 *
 * @author    EVL
 */
public interface OperatingSystemInspector
{
   /**
    * If there is still no match, then any <code>os.name</code> with the
    * lowercase text "unix" will return "UNIX" and any <code>os.name</code>
    * with the lowercase text "windows" will return "WIN32". 
    * <p>
    * If there is still no match, the <code>os.name</code> returned by the
    * Java will be returned. 
    *
    * @return   The name of the current operating system.
    */
   public String getOperatingSystem();

   /**
    * Gets the path separator character used to parse the Progress search
    * path.
    * <p>
    * The value returned may have been found via a search algorithm that
    * is account (user or process) specific or group specific
    * within the current server or a global default for all servers. 
    * <p>
    * If no value is found via this lookup, then the default value of
    * ':' will be returned.
    *
    * @return   The path to Progress source files.
    */
   public String getPathSeparator();

   /**
    * Checks is the current OS the P2J is running on belongs to the Windows
    * family.
    *
    * @return   <code>true</code> if the current OS is from Windows family or 
    *           <code>false</code> otherwise.
    */
   public logical isUnderWindowsFamily();
}
